import requests
import json

class client:
    def __init__(self, api_key, mode='chat'):
        if not api_key:
            raise ValueError("API key must be provided.")
        
        self.api_key = api_key
        self.mode = mode
        self.url = f'https://neuranet-ai.com/api/v1/{mode}'

    def generate(self, data, model=None):
        if self.mode == 'chat' and not model:
            raise ValueError("Model must be specified for chat mode.")

        headers = {
            'Authorization': f'Bearer {self.api_key}',
            'Content-Type': 'application/json'
        }

        if self.mode == 'chat':
            payload = {
                "settings": {"model": model},
                "conversation": {"history": data}
            }
        elif self.mode == 'image':
            payload = {
                "content": {"model": model, "prompt": data}
            }
        else:
            raise ValueError("Invalid mode. Mode should be either 'chat' or 'image'.")

        try:
            response = requests.post(self.url, headers=headers, data=json.dumps(payload))
            response.raise_for_status()
            if self.mode == 'chat':
                return response.json()['choices'][0]['text']
            elif self.mode == 'image':
                return response.json()['result'][0]['result-url']
        except requests.exceptions.HTTPError as http_err:
            if http_err.response.status_code == 403:
                raise PermissionError("Incorrect API key provided.")
            else:
                raise ConnectionError(f"HTTP error occurred: {http_err}")
        except requests.exceptions.RequestException as req_err:
            raise ConnectionError(f"Error occurred during request: {req_err}")
        except Exception as e:
            raise Exception(f"An unexpected error occurred: {e}")



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()
    
VERSION = '0.0.1'
DESCRIPTION = 'NeuraNET Python API library'
LONG_DESCRIPTION = 'NeuraNET Python API library'


setup(
    name='neuranet',
    version=VERSION,
    packages=find_packages(),
    install_requires=[
        "requests"
    ],
    author='Dark25 (Ruben Roy)',
    author_email='me@ruben-roy.com',
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords=['ai', 'machine learning', 'neuranet']
)
